@@ -174,8 +174,7 @@ class SqlStore:
     def get_db_by_table(self, table):
         farm = self.tables.get(table)
         if farm is None:
-            warn("Table %r is not configured, use default farm" % table,
-                    stacklevel=3)
+            print "Table %s not configure" % table
             return self.tables['*']
         else:
             return farm
