@@ -17,11 +17,12 @@ def get_db_by_table(table_name):
 from sqlbean.db import connection
 connection.get_db_by_table = get_db_by_table
 
-from sqlbean.shortcut import Model
+from sqlbean.shortcut import McModel
 
-class User(Model):
+class User(McModel):
     pass
 
+user = User()
 for i in User.where():
     print i.name
     
