@@ -176,12 +176,13 @@ class McModel(object):
     def raw_sql(cls,query,*args):
         result = Query.raw_sql(query, args, cls.db)
         return result
-    
+   
     def delete(self):
         'Deletes record from database'
         query = 'DELETE FROM %s WHERE `%s` = %%s' % (self.Meta.table_safe, self.Meta.pk)
         values = [getattr(self, self.Meta.pk)]
         Query.raw_sql(query, values, self.db)
+        self.mc_delete(id)
 
     def update(self,**kwds):
         set_what = ','.join(
@@ -275,9 +276,19 @@ class McModel(object):
         return self
 
     @classmethod
-    def get_or_create(cls,*args,**kwds):
-        ins = cls.get(*args,**kwds)
-        if not ins:
-            ins = cls(*args,**kwds)
-            ins.save()
+    def replace_into(cls,**kwds):
+        pk = cls.Meta.pk
+        if pk in kwds:
+            id = kwds[pk]
+            ins = cls.mc_get(id)
+            if ins is None:
+                ins = cls(id=id)
+            del kwds[pk]
+        else:
+            ins = cls()
+
+        for k,v in kwds.iteritems():
+            setattr(ins,k,v)
+        ins.save()
+
         return ins
